@@ -38,7 +38,7 @@ class Bootstrap4AlertsPlugin(CMSPluginBase):
 
     def render(self, context, instance, placeholder):
         link_classes = ['alert']
-        link_classes.append('alert-{}'.format(instance.alert_context))
+        link_classes.append(f'alert-{instance.alert_context}')
 
         classes = concat_classes(link_classes + [
             instance.attributes.get('class'),
