@@ -30,4 +30,4 @@ class Bootstrap4Alerts(CMSPlugin):
         return str(self.pk)
 
     def get_short_description(self):
-        return '({})'.format(self.alert_context)
+        return f'({self.alert_context})'
