@@ -40,13 +40,13 @@ CAROUSEL_ASPECT_RATIOS = (
     getattr(
         settings,
         'DJANGOCMS_BOOTSTRAP4_CAROUSEL_ASPECT_RATIOS',
-        tuple()
+        ()
     )
 )
 
 CAROUSEL_ASPECT_RATIO_CHOICES = (
-    tuple([
-        ('{0}x{1}'.format(x, y), '{0}x{1}'.format(x, y))
+    tuple(
+        (f'{x}x{y}', f'{x}x{y}')
         for x, y in CAROUSEL_ASPECT_RATIOS
-    ])
+    )
 )
