@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import migrations, models
 
 from ..constants import CAROUSEL_ASPECT_RATIO_CHOICES
