@@ -7,9 +7,7 @@ from djangocms_bootstrap4.constants import DEVICE_SIZES
 from djangocms_bootstrap4.helpers import concat_classes
 
 from .forms import Bootstrap4GridColumnForm, Bootstrap4GridRowForm
-from .models import (
-    Bootstrap4GridColumn, Bootstrap4GridContainer, Bootstrap4GridRow,
-)
+from .models import Bootstrap4GridColumn, Bootstrap4GridContainer, Bootstrap4GridRow
 
 
 class Bootstrap4GridContainerPlugin(CMSPluginBase):
@@ -83,11 +81,11 @@ class Bootstrap4GridRowPlugin(CMSPluginBase):
     def save_model(self, request, obj, form, change):
         super().save_model(request, obj, form, change)
         data = form.cleaned_data
-        for x in range(int(data['create']) if data['create'] is not None else 0):
+        for x in range(int(data['create']) if data['create'] is not None else 0):  # NOQA
             extra = {}
             for size in DEVICE_SIZES:
-                extra['{}_col'.format(size)] = data.get(
-                    'create_{}_col'.format(size)
+                extra[f'{size}_col'] = data.get(
+                    f'create_{size}_col'
                 )
             col = Bootstrap4GridColumn(
                 parent=obj,
@@ -140,11 +138,11 @@ class Bootstrap4GridColumnPlugin(CMSPluginBase):
         }),
         (_('Responsive settings'), {
             'fields': (
-                ['{}_col'.format(size) for size in DEVICE_SIZES],
-                ['{}_order'.format(size) for size in DEVICE_SIZES],
-                ['{}_offset'.format(size) for size in DEVICE_SIZES],
-                ['{}_ml'.format(size) for size in DEVICE_SIZES],
-                ['{}_mr'.format(size) for size in DEVICE_SIZES],
+                [f'{size}_col' for size in DEVICE_SIZES],
+                [f'{size}_order' for size in DEVICE_SIZES],
+                [f'{size}_offset' for size in DEVICE_SIZES],
+                [f'{size}_ml' for size in DEVICE_SIZES],
+                [f'{size}_mr' for size in DEVICE_SIZES],
             )
         }),
         (_('Advanced settings'), {
