@@ -1,17 +1,11 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from cms.models import CMSPlugin
 
-from six import python_2_unicode_compatible
-
 from djangocms_bootstrap4.fields import AttributesField, TagTypeField
 
 
-@python_2_unicode_compatible
 class Bootstrap4Jumbotron(CMSPlugin):
     """
     Components > "Jumbotron" Plugin
