@@ -1,14 +1,9 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from djangocms_picture.models import AbstractPicture
-from six import python_2_unicode_compatible
 
 
-@python_2_unicode_compatible
 class Bootstrap4Picture(AbstractPicture):
     """
     Content > "Image" Plugin
