@@ -5,10 +5,7 @@ from cms.models import CMSPlugin
 
 from djangocms_bootstrap4.fields import AttributesField, TagTypeField
 
-from .constants import (
-    TAB_ALIGNMENT_CHOICES, TAB_EFFECT_CHOICES, TAB_TEMPLATE_CHOICES,
-    TAB_TYPE_CHOICES,
-)
+from .constants import TAB_ALIGNMENT_CHOICES, TAB_EFFECT_CHOICES, TAB_TEMPLATE_CHOICES, TAB_TYPE_CHOICES
 
 
 class Bootstrap4Tab(CMSPlugin):
@@ -54,10 +51,10 @@ class Bootstrap4Tab(CMSPlugin):
         return str(self.pk)
 
     def get_short_description(self):
-        text = '({})'.format(self.tab_type)
+        text = f'({self.tab_type})'
 
         if self.tab_alignment:
-            text += ' .{}'.format(self.tab_alignment)
+            text += f' .{self.tab_alignment}'
         return text
 
 
