@@ -6,9 +6,7 @@ from cms.models import CMSPlugin
 from djangocms_bootstrap4.constants import DEVICE_CHOICES
 from djangocms_bootstrap4.fields import AttributesField, TagTypeField
 
-from .constants import (
-    SPACER_PROPERTY_CHOICES, SPACER_SIDE_CHOICES, SPACER_SIZE_CHOICES,
-)
+from .constants import SPACER_PROPERTY_CHOICES, SPACER_SIDE_CHOICES, SPACER_SIZE_CHOICES
 
 
 class Bootstrap4Spacing(CMSPlugin):
@@ -64,4 +62,4 @@ class Bootstrap4Spacing(CMSPlugin):
         )
 
     def get_short_description(self):
-        return '(.{})'.format(self.get_base_css_class())
+        return f'(.{self.get_base_css_class()})'
