@@ -1,8 +1,6 @@
 from django.test import TestCase
 
-from djangocms_bootstrap4.contrib.bootstrap4_badge.models import (
-    Bootstrap4Badge,
-)
+from djangocms_bootstrap4.contrib.bootstrap4_badge.models import Bootstrap4Badge
 
 
 class B4BadgeModelTestCase(TestCase):
