@@ -4,8 +4,7 @@ from cms.api import add_plugin
 from cms.test_utils.testcases import CMSTestCase
 
 from djangocms_bootstrap4.contrib.bootstrap4_grid.cms_plugins import (
-    Bootstrap4GridColumnPlugin, Bootstrap4GridContainerPlugin,
-    Bootstrap4GridRowPlugin,
+    Bootstrap4GridColumnPlugin, Bootstrap4GridContainerPlugin, Bootstrap4GridRowPlugin,
 )
 
 from ..fixtures import B4TestFixture
@@ -117,5 +116,5 @@ class B4GridPluginTestCase(B4TestFixture, CMSTestCase):
             # `get_add_plugin_uri` to get cleaner test results
             warnings.simplefilter("ignore")
             response = self.client.post(request_url, data)
-        self.assertEquals(response.status_code, 200)
+        self.assertEqual(response.status_code, 200)
         self.assertContains(response, '<div class="success">')
