@@ -1,8 +1,6 @@
 from django.test import TestCase
 
-from djangocms_bootstrap4.contrib.bootstrap4_jumbotron.models import (
-    Bootstrap4Jumbotron,
-)
+from djangocms_bootstrap4.contrib.bootstrap4_jumbotron.models import Bootstrap4Jumbotron
 
 
 class B4JumbotronModelTestCase(TestCase):
