@@ -1,8 +1,6 @@
 from django.test import TestCase
 
-from djangocms_bootstrap4.contrib.bootstrap4_picture.models import (
-    Bootstrap4Picture,
-)
+from djangocms_bootstrap4.contrib.bootstrap4_picture.models import Bootstrap4Picture
 
 
 class B4PictureModelTestCase(TestCase):
