@@ -1,8 +1,7 @@
 from django.test import TestCase
 
 from djangocms_bootstrap4.constants import (
-    ALIGN_CHOICES, COLOR_STYLE_CHOICES, DEVICE_CHOICES, DEVICE_SIZES,
-    TAG_CHOICES,
+    ALIGN_CHOICES, COLOR_STYLE_CHOICES, DEVICE_CHOICES, DEVICE_SIZES, TAG_CHOICES,
 )
 
 
@@ -11,15 +10,15 @@ class B4ConstantsTestCase(TestCase):
     # when changing any values in these
 
     def test_constants(self):
-        self.assertEquals(DEVICE_CHOICES, (
+        self.assertEqual(DEVICE_CHOICES, (
             ('xs', 'Extra small'),   # default <576px
             ('sm', 'Small'),         # default ≥576px
             ('md', 'Medium'),        # default ≥768px
             ('lg', 'Large'),         # default ≥992px
             ('xl', 'Extra large'),   # default ≥1200px
         ))
-        self.assertEquals(DEVICE_SIZES, ('xs', 'sm', 'md', 'lg', 'xl'))
-        self.assertEquals(TAG_CHOICES, (
+        self.assertEqual(DEVICE_SIZES, ('xs', 'sm', 'md', 'lg', 'xl'))
+        self.assertEqual(TAG_CHOICES, (
             ('div', 'div'),
             ('section', 'section'),
             ('article', 'article'),
@@ -27,7 +26,7 @@ class B4ConstantsTestCase(TestCase):
             ('footer', 'footer'),
             ('aside', 'aside')
         ))
-        self.assertEquals(COLOR_STYLE_CHOICES, (
+        self.assertEqual(COLOR_STYLE_CHOICES, (
             ('primary', 'Primary'),
             ('secondary', 'Secondary'),
             ('success', 'Success'),
@@ -37,7 +36,7 @@ class B4ConstantsTestCase(TestCase):
             ('light', 'Light'),
             ('dark', 'Dark'),
         ))
-        self.assertEquals(ALIGN_CHOICES, (
+        self.assertEqual(ALIGN_CHOICES, (
             ('text-left', 'Left'),
             ('text-center', 'Center'),
             ('text-right', 'Right'),
